==> octave-5.1.90-w64.zip: octave-2020-01-16-00-53-w64/mingw64/lib/cmake/Qhull/QhullTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qhull::qhullcpp" for configuration "Release"
set_property(TARGET Qhull::qhullcpp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qhullcpp PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/lib/libqhullcpp.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhullcpp )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhullcpp "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/lib/libqhullcpp.a" )

# Import target "Qhull::qhullstatic" for configuration "Release"
set_property(TARGET Qhull::qhullstatic APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qhullstatic PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C"
  IMPORTED_LOCATION_RELEASE "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/lib/libqhullstatic.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhullstatic )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhullstatic "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/lib/libqhullstatic.a" )

# Import target "Qhull::qhullstatic_r" for configuration "Release"
set_property(TARGET Qhull::qhullstatic_r APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qhullstatic_r PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C"
  IMPORTED_LOCATION_RELEASE "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/lib/libqhullstatic_r.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhullstatic_r )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhullstatic_r "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/lib/libqhullstatic_r.a" )

# Import target "Qhull::qhull_r" for configuration "Release"
set_property(TARGET Qhull::qhull_r APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qhull_r PROPERTIES
  IMPORTED_IMPLIB_RELEASE "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/lib/libqhull_r.dll.a"
  IMPORTED_LOCATION_RELEASE "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/libqhull_r.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull_r )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull_r "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/lib/libqhull_r.dll.a" "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/libqhull_r.dll" )

# Import target "Qhull::qhull" for configuration "Release"
set_property(TARGET Qhull::qhull APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qhull PROPERTIES
  IMPORTED_LOCATION_RELEASE "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/qhull.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/qhull.exe" )

# Import target "Qhull::rbox" for configuration "Release"
set_property(TARGET Qhull::rbox APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::rbox PROPERTIES
  IMPORTED_LOCATION_RELEASE "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/rbox.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::rbox )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::rbox "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/rbox.exe" )

# Import target "Qhull::qconvex" for configuration "Release"
set_property(TARGET Qhull::qconvex APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qconvex PROPERTIES
  IMPORTED_LOCATION_RELEASE "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/qconvex.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qconvex )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qconvex "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/qconvex.exe" )

# Import target "Qhull::qdelaunay" for configuration "Release"
set_property(TARGET Qhull::qdelaunay APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qdelaunay PROPERTIES
  IMPORTED_LOCATION_RELEASE "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/qdelaunay.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qdelaunay )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qdelaunay "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/qdelaunay.exe" )

# Import target "Qhull::qvoronoi" for configuration "Release"
set_property(TARGET Qhull::qvoronoi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qvoronoi PROPERTIES
  IMPORTED_LOCATION_RELEASE "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/qvoronoi.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qvoronoi )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qvoronoi "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/qvoronoi.exe" )

# Import target "Qhull::qhalf" for configuration "Release"
set_property(TARGET Qhull::qhalf APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qhalf PROPERTIES
  IMPORTED_LOCATION_RELEASE "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/qhalf.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhalf )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhalf "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/qhalf.exe" )

# Import target "Qhull::libqhull" for configuration "Release"
set_property(TARGET Qhull::libqhull APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::libqhull PROPERTIES
  IMPORTED_IMPLIB_RELEASE "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/lib/libqhull.dll.a"
  IMPORTED_LOCATION_RELEASE "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/libqhull.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::libqhull )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::libqhull "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/lib/libqhull.dll.a" "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/libqhull.dll" )

# Import target "Qhull::qhull_p" for configuration "Release"
set_property(TARGET Qhull::qhull_p APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qhull_p PROPERTIES
  IMPORTED_IMPLIB_RELEASE "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/lib/libqhull_p.dll.a"
  IMPORTED_LOCATION_RELEASE "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/libqhull_p.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull_p )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull_p "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/lib/libqhull_p.dll.a" "/home/siko1056/OctaveCD/build/mxe_stable_w64/usr/x86_64-w64-mingw32/bin/libqhull_p.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> octave-6.3.0-w64.zip: octave-6.3.0-w64/mingw64/lib/cmake/Qhull/QhullTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qhull::qhullcpp" for configuration "Release"
set_property(TARGET Qhull::qhullcpp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qhullcpp PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libqhullcpp.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhullcpp )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhullcpp "${_IMPORT_PREFIX}/lib/libqhullcpp.a" )

# Import target "Qhull::qhullstatic" for configuration "Release"
set_property(TARGET Qhull::qhullstatic APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qhullstatic PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libqhullstatic.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhullstatic )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhullstatic "${_IMPORT_PREFIX}/lib/libqhullstatic.a" )

# Import target "Qhull::qhullstatic_r" for configuration "Release"
set_property(TARGET Qhull::qhullstatic_r APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qhullstatic_r PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libqhullstatic_r.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhullstatic_r )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhullstatic_r "${_IMPORT_PREFIX}/lib/libqhullstatic_r.a" )

# Import target "Qhull::qhull_r" for configuration "Release"
set_property(TARGET Qhull::qhull_r APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qhull_r PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libqhull_r.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libqhull_r.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull_r )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull_r "${_IMPORT_PREFIX}/lib/libqhull_r.dll.a" "${_IMPORT_PREFIX}/bin/libqhull_r.dll" )

# Import target "Qhull::qhull" for configuration "Release"
set_property(TARGET Qhull::qhull APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qhull PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qhull.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull "${_IMPORT_PREFIX}/bin/qhull.exe" )

# Import target "Qhull::rbox" for configuration "Release"
set_property(TARGET Qhull::rbox APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::rbox PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/rbox.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::rbox )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::rbox "${_IMPORT_PREFIX}/bin/rbox.exe" )

# Import target "Qhull::qconvex" for configuration "Release"
set_property(TARGET Qhull::qconvex APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qconvex PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qconvex.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qconvex )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qconvex "${_IMPORT_PREFIX}/bin/qconvex.exe" )

# Import target "Qhull::qdelaunay" for configuration "Release"
set_property(TARGET Qhull::qdelaunay APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qdelaunay PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qdelaunay.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qdelaunay )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qdelaunay "${_IMPORT_PREFIX}/bin/qdelaunay.exe" )

# Import target "Qhull::qvoronoi" for configuration "Release"
set_property(TARGET Qhull::qvoronoi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qvoronoi PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qvoronoi.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qvoronoi )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qvoronoi "${_IMPORT_PREFIX}/bin/qvoronoi.exe" )

# Import target "Qhull::qhalf" for configuration "Release"
set_property(TARGET Qhull::qhalf APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qhalf PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/qhalf.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhalf )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhalf "${_IMPORT_PREFIX}/bin/qhalf.exe" )

# Import target "Qhull::libqhull" for configuration "Release"
set_property(TARGET Qhull::libqhull APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::libqhull PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libqhull.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libqhull.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::libqhull )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::libqhull "${_IMPORT_PREFIX}/lib/libqhull.dll.a" "${_IMPORT_PREFIX}/bin/libqhull.dll" )

# Import target "Qhull::qhull_p" for configuration "Release"
set_property(TARGET Qhull::qhull_p APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qhull::qhull_p PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libqhull_p.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libqhull_p.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qhull::qhull_p )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qhull::qhull_p "${_IMPORT_PREFIX}/lib/libqhull_p.dll.a" "${_IMPORT_PREFIX}/bin/libqhull_p.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
